======================
LibRapid NDarray
======================

:class:`ndarray::basic_ndarray`
:func:`ndarray::basic_ndarray::set_stride`

Is this a title?
----------------

This is the contents of the ndarray module
